==> 1.3.0.tar.gz: manager/pages/regions.php <==
<?php
	$HTML->setHTMLTitle("Deine Regionen");
	$HTML->importSeitenInhalt("deine-regionen.html");

    function cleanSize($bytes)
    {
        if ($bytes > 0)
        {
            $unit = intval(log($bytes, 1024));
            $units = array('B', 'KB', 'MB', 'GB');
    
            if (array_key_exists($unit, $units) === true)
            {
                return sprintf('%d %s', $bytes / pow(1024, $unit), $units[$unit]);
            }
        }
    
        return $bytes;
    }

    function getRegionStatsData($regionID)
    {
        global $RUNTIME;

        $statement = $RUNTIME['PDO']->prepare("SELECT Prims,SimFPS,PhyFPS,ProcMem,RegionVersion FROM regions_info WHERE regionID = ?");
        $statement->execute([$regionID]); 

        if($row = $statement->fetch())
        {
            $return = array();
            $return['Prims'] = $row['Prims'];
            $return['SimFPS'] = $row['SimFPS'];
            $return['PhyFPS'] = $row['PhyFPS'];
            $return['ProcMem'] = cleanSize(str_replace(".", "", str_replace(",", ".", $row['ProcMem']))."000");
            $return['RegionVersion'] = trim($row['RegionVersion']);

            return $return;
        }

        return array();
    }

    if($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_REQUEST['remove']))
    {
        include 'app/FormValidator.php';
        $validator = new FormValidator(array(
            'region' => array('required' => true, 'regex' => '/^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/')
        ));

        if($validator->isValid($_POST)) {
            if(isset($_SESSION['LEVEL']) && $_SESSION['LEVEL'] >= 100) {
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM regions WHERE uuid = ?");
                $statementMembership->execute(array($_POST['region']));
            } else {
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM regions WHERE uuid = ? AND owner_uuid = ?");
                $statementMembership->execute(array($_POST['region'], $_SESSION['UUID']));
            }
        }

        header('Location: index.php?page=regions');
        die();
    }

    $table = '<table class="table"><thead><tr><th scope="col">Region Name</th><th scope="col">Eigentümer</th><th scope="col">Position</th><th scope="col">Aktionen</th></thead><tbody>%%ENTRY%%</tbody></table>';

    $showAll = isset($_SESSION['LEVEL']) && $_SESSION['LEVEL'] >= 100 && isset($_REQUEST['SHOWALL']) && $_REQUEST['SHOWALL'] == "1";
    $statement = $RUNTIME['PDO']->prepare("SELECT uuid,regionName,owner_uuid,locX,locY FROM regions ".($showAll ? "ORDER BY owner_uuid ASC" : "WHERE owner_uuid = ? ORDER BY uuid ASC"));
    $statement->execute($showAll ? array() : array($_SESSION['UUID'])); 

    include 'app/OpenSim.php';
    $opensim = new OpenSim();

    while($row = $statement->fetch()) 
    {
        $stats = getRegionStatsData($row['uuid']);

        $entry = '<tr><td>'.htmlspecialchars($row['regionName']).'<div class="blockquote-footer">Prims: '.$stats['Prims'].'; RAM-Nutzung: '.$stats['ProcMem'].'; SIM/PHYS FPS: '.$stats['SimFPS'].'/'.$stats['PhyFPS'].' ('.$stats['RegionVersion'].')</div></td><td>'.htmlspecialchars($opensim->getUserName($row['owner_uuid'])).'</td><td>'.fillString(($row['locX'] / 256), 4).' / '.fillString(($row['locY'] / 256), 4).'</td><td><form action="index.php?page=regions" method="post">%%CSRF%%<input type="hidden" name="region" value="'.$row['uuid'].'"><button type="submit" name="remove" class="btn btn-link btn-sm">LÖSCHEN</button></form></td></tr>';       
        $table = str_replace("%%ENTRY%%", $entry."%%ENTRY%%", $table);
    }

    $table = str_replace("%%ENTRY%%", "", $table);
    $HTML->ReplaceSeitenInhalt("%%REGION-LIST%%", $table);

    $HTML->build();
    echo $HTML->ausgabe();
?>

==> 1.4.0.tar.gz: manager/pages/regions.php <==
<?php
    $HTML->setHTMLTitle("Deine Regionen");
    $HTML->importSeitenInhalt("deine-regionen.html");

    function cleanSize($bytes)
    {
        if ($bytes > 0) {
            $unit = intval(log($bytes, 1024));
            $units = array('B', 'KB', 'MB', 'GB');
    
            if (array_key_exists($unit, $units) === true) {
                return sprintf('%d %s', $bytes / pow(1024, $unit), $units[$unit]);
            }
        }
    
        return $bytes;
    }

    function getRegionStatsData($regionID)
    {
        global $RUNTIME;

        $statement = $RUNTIME['PDO']->prepare("SELECT Prims,SimFPS,PhyFPS,ProcMem,RegionVersion FROM regions_info WHERE regionID = ?");
        $statement->execute([$regionID]);

        if ($row = $statement->fetch()) {
            $return = array();
            $return['Prims'] = $row['Prims'];
            $return['SimFPS'] = $row['SimFPS'];
            $return['PhyFPS'] = $row['PhyFPS'];
            $return['ProcMem'] = cleanSize(str_replace(".", "", str_replace(",", ".", $row['ProcMem']))."000");
            $return['RegionVersion'] = trim($row['RegionVersion']);

            return $return;
        }

        return array();
    }

    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_REQUEST['remove'])) {
        include_once 'app/FormValidator.php';
        $validator = new FormValidator(array(
            'region' => array('required' => true, 'regex' => '/^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/')
        ));

        if ($validator->isValid($_POST)) {
            if (isset($_SESSION['LEVEL']) && $_SESSION['LEVEL'] >= 100) {
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM regions WHERE uuid = ?");
                $statementMembership->execute(array($_POST['region']));
            } else {
                $statementMembership = $RUNTIME['PDO']->prepare("DELETE FROM regions WHERE uuid = ? AND owner_uuid = ?");
                $statementMembership->execute(array($_POST['region'], $_SESSION['UUID']));
            }
        }

        header('Location: index.php?page=regions');
        die();
    }

    $table = '<table class="table"><thead><tr><th scope="col">Region Name</th><th scope="col">Eigentümer</th><th scope="col">Position</th><th scope="col">Aktionen</th></thead><tbody>%%ENTRY%%</tbody></table>';

    $showAll = isset($_SESSION['LEVEL']) && $_SESSION['LEVEL'] >= 100 && isset($_REQUEST['SHOWALL']) && $_REQUEST['SHOWALL'] == "1";
    $statement = $RUNTIME['PDO']->prepare("SELECT uuid,regionName,owner_uuid,locX,locY FROM regions ".($showAll ? "ORDER BY owner_uuid ASC" : "WHERE owner_uuid = ? ORDER BY uuid ASC"));
    $statement->execute($showAll ? array() : array($_SESSION['UUID']));

    include_once 'app/OpenSim.php';
    $opensim = new OpenSim();

    while ($row = $statement->fetch()) {
        $stats = getRegionStatsData($row['uuid']);

        $entry = '<tr><td>'.htmlspecialchars($row['regionName']).'<div class="blockquote-footer">'.(!empty($stats) ? 'Prims: '.$stats['Prims'].'; RAM-Nutzung: '.$stats['ProcMem'].'; SIM/PHYS FPS: '.$stats['SimFPS'].'/'.$stats['PhyFPS'].' ('.$stats['RegionVersion'].')' : 'Keine Statistik verfügbar').'</div></td><td>'.htmlspecialchars($opensim->getUserName($row['owner_uuid'])).'</td><td>'.fillString(($row['locX'] / 256), 4).' / '.fillString(($row['locY'] / 256), 4).'</td><td><form action="index.php?page=regions" method="post">%%CSRF%%<input type="hidden" name="region" value="'.$row['uuid'].'"><button type="submit" name="remove" class="btn btn-link btn-sm">LÖSCHEN</button></form></td></tr>';
        $table = str_replace("%%ENTRY%%", $entry."%%ENTRY%%", $table);
    }

    $table = str_replace("%%ENTRY%%", "", $table);
    $HTML->ReplaceSeitenInhalt("%%REGION-LIST%%", $table);

    $HTML->build();
    echo $HTML->ausgabe();
